@@ -1,9 +1,11 @@
-__version__ = "0.0.1"
+__version__ = "0.0.2"
 
 from ._vem_pixel_classifier import VEMSEGClassifier
 from ._predict_pixel_classifier import VEMSEGClassifierPredict
+from . _phh_predict import PHHPredictWidget
 
 __all__ = (
     "VEMSEGClassifier",
-    "VEMSEGClassifierPredict"
+    "VEMSEGClassifierPredict",
+    "PHHPredictWidget"
 )
